﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using GameControl.Properties;
using System.Threading;
using System.Runtime.InteropServices;
using System.IO;

namespace GameControl
{
    public partial class frmMain : Form
    {
        private int numOne = 0;
        private int numTwo = 0;
        private int operate = 0;
        private int result = 0;

        public int num = 0;
        public int maxNum = 10;
        public int Minutes = 20;

        public int limitsMin = 1;
        public int limitsMax = 10;

        public string passWord = "admin";

        public frmExit frmexit = new frmExit();

        private int operateMin = 1;
        private int operateMax = 4;

        System.DateTime startTime = System.DateTime.Now;
        System.DateTime endTime = System.DateTime.Now;
        System.TimeSpan ts;

        private const int SC_CLOSE = 0xF060;
        private const int MF_ENABLED = 0x00000000;
        private const int MF_GRAYED = 0x00000001;
        private const int MF_DISABLED = 0x00000002;

        [DllImport("user32.dll", EntryPoint = "GetSystemMenu")]
        private static extern IntPtr GetSystemMenu(IntPtr hWnd, int bRevert);
        [DllImport("User32.dll")]
        public static extern bool EnableMenuItem(IntPtr hMenu, int uIDEnableItem, int uEnable);

       public frmMain()
        {
            InitializeComponent();

            IntPtr hMenu = GetSystemMenu(this.Handle, 0);
            EnableMenuItem(hMenu, SC_CLOSE, MF_DISABLED | MF_GRAYED);

            init();
        }

        /// <summary>
        /// 初始化函数
        /// </summary>
        public void init()
        {
            timer1.Enabled = false;
            if (File.Exists(Application.StartupPath + "\\config.ini"))
            {
                //读取配置文件
                StreamReader objReader = new StreamReader(Application.StartupPath + "\\config.ini");

                string sLine = "";
                string[] configTxt;

                do
                {
                    sLine = objReader.ReadLine();
                    if (sLine != null)
                    {
                        configTxt = sLine.Split(':');
                        switch (configTxt[0])
                        {
                            case "游戏时间":
                                try
                                {
                                    Minutes = int.Parse(configTxt[1]);
                                }
                                catch { }
                                break;
                            case "出题数":
                                try
                                {
                                    maxNum = int.Parse(configTxt[1]);
                                }
                                catch { }
                                break;
                            case "出题最小数字":
                                try
                                {
                                    limitsMin = int.Parse(configTxt[1]);
                                }
                                catch { }
                                break;
                            case "出题最大数字":
                                try
                                {
                                    limitsMax = int.Parse(configTxt[1]);
                                }
                                catch { }
                                break;
                            case "退出密码":
                                try
                                {
                                    passWord = configTxt[1];
                                    passWord = EncryptionDecryption.decode(passWord);
                                }
                                catch { }
                                break;
                        }
                    }
                } while (sLine != null);
                objReader.Close();
            }

            frmexit.exitPassword = passWord;
            startTime = System.DateTime.Now;
            this.labTag.Text = "共有" + maxNum + "道题，已完成" + num + "道题";
            timer1.Enabled = true;
        }

        protected override CreateParams CreateParams
        {
            get
            {
                const int CS_NOCLOSE = 0x200;
                CreateParams cp = base.CreateParams;
                cp.ClassStyle = cp.ClassStyle | CS_NOCLOSE;
                return cp;
            }
        }

        private void frmMain_SizeChanged(object sender, EventArgs e)
        {
            if (this.WindowState == FormWindowState.Minimized) { 
                this.Hide();
                this.notifyIcon1.Visible = true; 
            }
        }

        private void notifyIcon1_Click(object sender, EventArgs e)
        {
            this.contextMenuStrip1.Show(MousePosition.X, MousePosition.Y);
        }

        private void MenuItemExit_Click(object sender, EventArgs e)
        {
            frmexit.Text = "退出";
            frmexit.ShowDialog(this);
            
            if (frmexit.isExit)
            {
                this.Close();
                //e.Cancel = true;
                //frmexit.ShowDialog(this);
            }
        }

        private void frmMain_Load(object sender, EventArgs e)
        {
            GetNext();
            this.Hide();
        }

        /// <summary>
        /// 获取下一组计算题
        /// </summary>
        private void GetNext()
        {
            numOne = GetRandom(limitsMin, limitsMax);
            numTwo = GetRandom(limitsMin, limitsMax);
            operate = GetRandom(operateMin, operateMax);

            if (operate > operateMax / 2)
            {
                this.labOperate.Text = "+";
                result = numOne + numTwo;
            }
            else
            {
                this.labOperate.Text = "-";
                operate = Math.Max(numOne, numTwo);
                numTwo = Math.Min(numOne, numTwo);
                numOne = operate;
                result = numOne - numTwo;
            }

            this.labNumOne.Text = numOne.ToString();
            this.labNumTwo.Text = numTwo.ToString();

            this.txtResult.Text = "";
            this.txtResult.Focus();
        }

        /// <summary>
        /// 生成随机数
        /// </summary>
        /// <param name="min">随机数最小界值</param>
        /// <param name="max">随机数最大界值</param>
        /// <returns>生成的随机数</returns>
        private int GetRandom(int min,int max)
        {
            Thread.Sleep(100);
            Random rd = new Random(unchecked((int)DateTime.Now.Ticks));
            int i = rd.Next(min,max + 1);

            return i;
        }

        private void btnCheck_Click(object sender, EventArgs e)
        {

            if (txtResult.Text == result.ToString())
            {
                pcbResult.Image = Resources.right;
                num++;
                this.labTag.Text = "共有" + maxNum + "道题，已完成" + num + "道题";
                if (num >= maxNum)
                {
                    this.WindowState = FormWindowState.Minimized;
                    timer1.Enabled = true;
                    this.startTime = System.DateTime.Now;

                    num = 0;
                }
                else
                    GetNext();
            }
            else
            {
                pcbResult.Image = Resources.error;
            }
            
            this.txtResult.Text = "";
            this.txtResult.Focus();
        }

        private void btnSkip_Click(object sender, EventArgs e)
        {
            GetNext();
        }

        private void btnLook_Click(object sender, EventArgs e)
        {
            string msg = this.labNumOne.Text + this.labOperate.Text + this.labNumTwo.Text + "=" + this.result.ToString();
            MessageBox.Show(msg,"提示",MessageBoxButtons.OK,MessageBoxIcon.Information);
            GetNext();
        }

        private void timer1_Tick(object sender, EventArgs e)
        {
            endTime = System.DateTime.Now;
            ts = endTime - startTime;
            if (ts.Minutes >= Minutes)
            {
                this.WindowState = FormWindowState.Maximized;
                timer1.Enabled = false;
                this.Show();
                GetNext();
            }
            else
                Console.WriteLine(ts.Seconds);
        }

        private void notifyIcon1_DoubleClick(object sender, EventArgs e)
        {
            this.WindowState = FormWindowState.Maximized;
            timer1.Enabled = false;
            GetNext();
            this.Show();
        }

        private void frmMain_FormClosing(object sender, FormClosingEventArgs e)
        {
        }

        private void MenuItemAbout_Click(object sender, EventArgs e)
        {
            //显示关于窗口
            frmAbout fa = new frmAbout();
            fa.Show(this);
        }

        private void MenuItemSeting_Click(object sender, EventArgs e)
        {
            //显示设置窗口
            frmexit.Text = "设置";
            frmexit.ShowDialog(this);

            if (frmexit.isExit)
            {
                frmexit.isExit = false;

                frmSeting fs = new frmSeting();

                fs.nudMinutes.Value = Minutes;
                fs.nudMaxNum.Value = maxNum;
                fs.nudLimitsMin.Value = limitsMin;
                fs.nudLimitsMax.Value = limitsMax;
                fs.txtPassword.Text = passWord;
                fs.txtAgePwd.Text = passWord;

                fs.ShowDialog(this);

                if (fs.bSet)
                {
                    init();
                }
            }
        }
    }
}
